@@ -151,18 +151,6 @@ to_build_duration <- function(x) {
 
 time_columns <- c("elapsed", "user", "system")
 
-finalize_times <- function(target, meta, config) {
-  meta$time_command <- runtime_entry(
-    runtime = meta$time_command,
-    target = target
-  )
-  meta$time_build <- runtime_entry(
-    runtime = proc.time() - meta$time_start,
-    target = target
-  )
-  meta
-}
-
 is_bad_time <- function(x) {
   !length(x) || is.na(x[1])
 }
